@@ -2,7 +2,7 @@ import logging
 
 import telepathy
 
-import gtk_toolbox
+import util.misc as misc_utils
 
 
 _moduleLogger = logging.getLogger('location')
@@ -22,21 +22,21 @@ class LocationMixin(object):
 		"""
 		raise NotImplementedError("Abstract property called")
 
-	@gtk_toolbox.log_exception(_moduleLogger)
+	@misc_utils.log_exception(_moduleLogger)
 	def GetLocations(self, contacts):
 		"""
 		@returns {Contact: {Location Type: Location}}
 		"""
 		raise telepathy.errors.NotImplemented("Yet")
 
-	@gtk_toolbox.log_exception(_moduleLogger)
+	@misc_utils.log_exception(_moduleLogger)
 	def RequestLocation(self, contact):
 		"""
 		@returns {Location Type: Location}
 		"""
 		raise telepathy.errors.NotImplemented("Yet")
 
-	@gtk_toolbox.log_exception(_moduleLogger)
+	@misc_utils.log_exception(_moduleLogger)
 	def SetLocation(self, location):
 		"""
 		Since presence is based off of phone numbers, not allowing the client to change it
